==> photo-uploader-0.2.tar.bz2: photo-uploader-0.2/phoupl/services/droxi.py <==
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
'''
Photo-Uploader wrapper for Droxi service.
'''
__author__ = 'Michal Čihař'
__email__ = 'michal@cihar.com'
__license__ = '''
Copyright © 2007 Michal Čihař

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License version 2 as published by
the Free Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
'''

import phoupl
import pycurl

class DroxiService(phoupl.core.PhotoUploader):
    def _connect(self):
        # Use preseeded session
        if self._session is not None:
            self.msg('Reusing session %s' % self._session)
            return

        # Init session...
        self.msg('Initialising session...')
        self.get('http://foto.droxi.cz/')
        self.cookies = self._curl.getinfo(pycurl.INFO_COOKIELIST)
        self._session = self.cookies[0].split('\t')[6]
        self.msg('Created session %s' % self._session)

        # Select photo and not photoalbum...
        self.msg('Selecting photo order...')
        self.post('http://foto.droxi.cz/index.php',
                [
                    ('scripttest', '0'), 
                    ('vyber', 'fotka')
                ])

        # Select fast/cheaper/simple order...
        self.msg('Selecting fast/cheaper/simple order...')
        self.post('http://foto.droxi.cz/typ-zakazky/index.php',
                [
                    ('krok_zpet', '4'), 
                    ('set_ordertype', 'disc'), 
                    ('pokracovat', 'some text')
                ])

    def _upload(self, image):
        self.post(
                'http://foto.droxi.cz/vlozit-fotografie/upload.php?ilikephoto=%s&verze=droxi' % self._session,
                [
                    ('sessionid',  self._session), 
                    ('f1', (pycurl.FORM_FILE, image)), 
                    ('nf1', ''),
                    ('pokracovat', 'some text')
                ])

    def _post_upload(self):
        self.msg('''
You can review them here:
http://foto.droxi.cz/prehled-vlozenych-fotografii/?ilikephoto=%s
You can finish order here:
http://foto.droxi.cz/format-fotografii/?ilikephoto=%s
''' %(self._session, self._session))

    def get_review_url(self):
        return 'http://foto.droxi.cz/prehled-vlozenych-fotografii/?ilikephoto=%s' % self._session

# Register service
phoupl.register_service(
        'droxi.cz', 
        DroxiService,
        'http://foto.droxi.cz/',
        ['new', 'reuse'],
        'Droxi',
        ['cz'],
        ['cze']
        )

==> photo-uploader_0.11.orig.tar.bz2: photo-uploader-0.11/phoupl/services/droxi.py <==
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
'''
Photo-Uploader wrapper for Droxi service.
'''
__author__ = 'Michal Čihař'
__email__ = 'michal@cihar.com'
__license__ = '''
Copyright © 2007 - 2010 Michal Čihař

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License version 2 as published by
the Free Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
'''

import phoupl
import phoupl.ilikephoto
import pycurl

class DroxiService(phoupl.core.PhotoUploader, phoupl.ilikephoto.ILikePhoto):
    def _connect(self):
        phoupl.ilikephoto.ILikePhoto.__init__(self, 'http://foto.droxi.cz', 'droxi')
        # Use preseeded session
        if self._session is not None:
            self.msg('Reusing session %s' % self._session)
            return

        # Init session...
        self.ipl_init_session()

        # Select fast/cheaper/simple order...
        self.ipl_select_simple()

    def _upload(self, image):
        self.ipl_upload(image)

    def _post_upload(self):
        self.ipl_post_upload()

    def get_review_url(self):
        return self.ipl_get_review_url()

    def ipl_get_simple_url(self):
        return '%s/typ-zakazky/index.php' % self._baseurl

# Register service
phoupl.register_service(
        'droxi.cz',
        DroxiService,
        'http://foto.droxi.cz/',
        ['new', 'reuse'],
        'Droxi',
        ['cz'],
        ['cze']
        )
